﻿using UnityEngine;
using UnityEngine.UI;
using System.Collections;

public class CameraController : MonoBehaviour
{

    public static CameraController instance;

    public Transform target;
    public float distance = 3.0f;
    public float height = 3.0f;
    public float damping = 5.0f;
    public bool smoothRotation = true;
    public float rotationDamping = 10.0f;
    public Text RespawnText;
    public Text KillsText;
    public Text DeathText;
    public Text Retry;
    public Text MainMenu;

    public int KillCount;
    public int DeathCount;


    public UI_Controller Mobile_Gas;
    public UI_Controller Mobile_Brake;
    public UI_Controller Mobile_Right;
    public UI_Controller Mobile_Left;
    public UI_Controller Mobile_Shoot;


    public GameObject MobileController;



    void Start()
    {


        if (!Retry)
        {
            return;
        }

        int lng = PlayerPrefs.GetInt("language");

        if (lng == 0)
        {
            Retry.text = "TEKRAR OYNA";
            MainMenu.text = "ANA MENÜ";
        }
        if (lng == 1)
        {
            Retry.text = "RETRY";
            MainMenu.text = "MAIN MENU";
        }
        if (lng == 2)
        {
            Retry.text = "RECOMMENCEZ";
            MainMenu.text = "MENU PRINCIPAL";
        }
        if (lng == 3)
        {
            Retry.text = "WIEDERHOLEN";
            MainMenu.text = "HAUPTMENÜ";
        }
    }
            

    public void Close()
    {
        int lng = PlayerPrefs.GetInt("language");

        if(PhotonNetwork.connected)
        PhotonNetwork.Disconnect();
       // Destroy(PhotonNetworkManager.instance.gameObject);

        if(lng == 0)
        {
            Application.LoadLevel("Menu_TR");
        }
        if (lng == 1)
        {
            Application.LoadLevel("Menu");
        }
        if (lng == 2)
        {
            Application.LoadLevel("Menu_FRA");
        }
        if (lng == 3)
        {
            Application.LoadLevel("Menu_ALM");
        }

    }


    void Awake()
    {
        instance = this;
        RespawnText.text = "";
        ResetBottomTexts();

#if UNITY_STANDALONE
        MobileController.SetActive(false);
#endif

#if UNITY_ANDROID
         MobileController.SetActive(true);
#endif

    }

    public void ResetBottomTexts()
    {
        KillsText.text = "Kills\n0";
        DeathText.text = "Deaths\n0";


        int lng = PlayerPrefs.GetInt("language");

        if (lng == 0)
        {
            KillsText.text = "Oldurulen\n0";
            DeathText.text = "Olum\n0";
        }
        if (lng == 1)
        {
            KillsText.text = "Kills\n0";
            DeathText.text = "Deaths\n0";
        }
        if (lng == 2)
        {
            KillsText.text = "Tue\n0";
            DeathText.text = "Mort\n0";
        }
        if (lng == 3)
        {
            KillsText.text = "Totet\n0";
            DeathText.text = "Todesfälle\n0";
        }


    }

    public void RetryButton()
    {
        UnityEngine.SceneManagement.SceneManager.LoadScene("singlePlayer");
    }
    public void MainMenuButton()
    {
        int lng = PlayerPrefs.GetInt("language");

        if (PhotonNetwork.connected)
            PhotonNetwork.Disconnect();
        // Destroy(PhotonNetworkManager.instance.gameObject);

        if (lng == 0)
        {
            Application.LoadLevel("Menu_TR");
        }
        if (lng == 1)
        {
            Application.LoadLevel("Menu");
        }
        if (lng == 2)
        {
            Application.LoadLevel("Menu_FRA");
        }
        if (lng == 3)
        {
            Application.LoadLevel("Menu_ALM");
        }

    }

    public void AddScore(bool isKill)
    {
        int lng = PlayerPrefs.GetInt("language");

        if (isKill)
        {
            KillCount += 1;

           // KillsText.text = "Kills\n" + KillCount.ToString();

            if (lng == 0)
            {
                KillsText.text = "Oldurulen\n" + KillCount.ToString();
            }
            if (lng == 1)
            {
                KillsText.text = "Kills\n" + KillCount.ToString();
            }
            if (lng == 2)
            {
                KillsText.text = "Tue\n" + KillCount.ToString();
            }
            if (lng == 3)
            {
                KillsText.text = "Totet\n" + KillCount.ToString();
            }
        }
        else
        {
            DeathCount += 1;

            //DeathText.text = "Deaths\n" + DeathCount.ToString();

            if (lng == 0)
            {
                DeathText.text = "Olum\n" + DeathCount.ToString();
            }
            if (lng == 1)
            {
                DeathText.text = "Deaths\n" + DeathCount.ToString();
            }
            if (lng == 2)
            {
                DeathText.text = "Mort\n" + DeathCount.ToString();
            }
            if (lng == 3)
            {
                DeathText.text = "Todesfälle\n" + DeathCount.ToString();
            }

        }

    }

    public void Respawn()
    {
        StartCoroutine(_Respawn());
    }

    IEnumerator _Respawn()
    {
        RespawnText.text = "You will respawn in 5 seconds";
        yield return new WaitForSeconds(1);
        RespawnText.text = "You will respawn in 4 seconds";
        yield return new WaitForSeconds(1);
        RespawnText.text = "You will respawn in 3 seconds";
        yield return new WaitForSeconds(1);
        RespawnText.text = "You will respawn in 2 seconds";
        yield return new WaitForSeconds(1);
        RespawnText.text = "You will respawn in 1 seconds";
        yield return new WaitForSeconds(1);
        RespawnText.text = "";
        //Spawn

        PhotonNetworkManager.instance.Spawn();



    }

    void Update()
    {
        if (!target)
        {
            return;
        }

        Vector3 wantedPosition = target.TransformPoint(0, height, distance);
        transform.position = Vector3.Lerp(transform.position, wantedPosition, Time.deltaTime * damping);

        if (smoothRotation)
        {
            Quaternion wantedRotation = Quaternion.LookRotation(target.position - transform.position, target.up);
            transform.rotation = Quaternion.Slerp(transform.rotation, wantedRotation, Time.deltaTime * rotationDamping);
        }

        else transform.LookAt(target, target.up);
    }
}